@@ -3,8 +3,9 @@ package HTTP::Headers;
 use strict;
 use warnings;
 
-our $VERSION = '6.31';
+our $VERSION = '7.00';
 
+use Clone qw(clone);
 use Carp ();
 
 # The $TRANSLATE_UNDERSCORE variable controls whether '_' can be used
@@ -151,7 +152,7 @@ sub _header
     my($self, $field, $val, $op) = @_;
 
     Carp::croak("Illegal field name '$field'")
-        if ( $field !~ /^X-\w/ && rindex($field, ':') > 1) || !length($field);
+        if rindex($field, ':') > 1 || !length($field);
 
     unless ($field =~ /^:/) {
 	$field =~ tr/_/-/ if $TRANSLATE_UNDERSCORE;
@@ -298,19 +299,6 @@ sub _process_newline {
 }
 
 
-
-if (eval { require Clone; 1 }) {
-    *clone = \&Clone::clone;
-} else {
-    *clone = sub {
-	my $self = shift;
-	my $clone = HTTP::Headers->new;
-	$self->scan(sub { $clone->push_header(@_);} );
-	$clone;
-    };
-}
-
-
 sub _date_header
 {
     require HTTP::Date;
@@ -475,7 +463,7 @@ HTTP::Headers - Class encapsulating HTTP Message headers
 
 =head1 VERSION
 
-version 6.31
+version 7.00
 
 =head1 SYNOPSIS
 
